﻿using Hotline.KnowledgeBase;
using Hotline.Share.Dtos.Knowledge;
using Hotline.Share.Dtos;
using Hotline.Share.Enums.KnowledgeBase;
using Microsoft.AspNetCore.Mvc;
using SqlSugar;
using Hotline.Settings;
using Hotline.Repository.SqlSugar.Extensions;

namespace Hotline.Api.Controllers.Bi
{
	public class BiKnowledgeController : BaseController
	{
		private readonly IKnowledgeRepository _knowledgeRepository;
		public BiKnowledgeController(IKnowledgeRepository knowledgeRepository) 
		{
			_knowledgeRepository = knowledgeRepository;
		}

		/// <summary>
		///知识库数据统计
		/// </summary>
		/// <param name="dto"></param>
		/// <returns></returns>
		[HttpGet("data_list")]
		public async Task<PagedDto<KnowledgeBiDataListVo>> DataList([FromQuery] KnowledgeBiDataListDto dto)
		{
			var query = _knowledgeRepository.Queryable(false,true,false)
				.LeftJoin<SystemOrganize>((x,o)=>x.SourceOrganizeId == o.Id)
				.WhereIF(dto.CreationTimeStart.HasValue, (x,o) => x.CreationTime >= dto.CreationTimeStart)
				.WhereIF(dto.CreationTimeEnd.HasValue, (x,o)=> x.CreationTime <= dto.CreationTimeEnd)
				.WhereIF(!string.IsNullOrEmpty(dto.Keyword),(x,o)=> o.Name.Contains(dto.Keyword!))
				.GroupBy((x,o) =>  new { x.SourceOrganizeId, o.Name, o.OrgType })
				.Select((x,o) => new KnowledgeBiDataListVo
				{
					OrgName = o.Name,
					OrgId = x.SourceOrganizeId,
					OrgType = o.OrgType,
					AddNum = SqlFunc.AggregateSum(SqlFunc.IIF(x.Status == EKnowledgeStatus.OnShelf, 1, 0)),
					DeleteNum = SqlFunc.AggregateSum(SqlFunc.IIF(x.IsDeleted, 1, 0)),
					SendBackNum = SqlFunc.AggregateSum(SqlFunc.IIF(x.Status == EKnowledgeStatus.Revert, 1, 0)),
					PassNum = SqlFunc.AggregateSum(SqlFunc.IIF(x.Status == EKnowledgeStatus.OnShelf, 1, 0))
				}).MergeTable();
			switch (dto.SortField)
			{
				case "addNum":
					query = dto.SortRule == 0 ? query.OrderBy(x => x.AddNum) : query.OrderByDescending(x => x.AddNum);
					break;
				case "deleteNum":
					query = dto.SortRule == 0 ? query.OrderBy(x => x.DeleteNum) : query.OrderByDescending(x => x.DeleteNum);
					break;
				case "sendBackNum":
					query = dto.SortRule == 0 ? query.OrderBy(x => x.SendBackNum) : query.OrderByDescending(x => x.SendBackNum);
					break;
				case "passNum":
					query = dto.SortRule == 0 ? query.OrderBy(x => x.PassNum) : query.OrderByDescending(x => x.PassNum);
					break;
			}
            var (total, items) = await query.ToPagedListAsync(dto, HttpContext.RequestAborted);
            return new PagedDto<KnowledgeBiDataListVo>(total, items);
		}
	}
}
