﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Hotline.DataSharing.Province.Notifications;
using Hotline.Orders;
using Hotline.Share.Enums.Order;
using MapsterMapper;
using MediatR;
using Microsoft.AspNetCore.Http;
using XF.Domain.Exceptions;
using XF.Domain.Repository;

namespace Hotline.Application.Handlers.Order
{
    public class OrderSendBackResultNotifyHandler : INotificationHandler<OrderSendBackResultNotify>
    {
        private readonly IRepository<OrderSendBack> _orderSendBackRepository;
        private readonly IOrderRepository _orderRepository;
        private readonly IMapper _mapper;

        public OrderSendBackResultNotifyHandler(
            IRepository<OrderSendBack> orderSendBackRepository,
            IOrderRepository orderRepository,
            IMapper mapper)
        {
            _orderSendBackRepository = orderSendBackRepository;
            _orderRepository = orderRepository;
            _mapper = mapper;
        }

        /// <summary>Handles a notification</summary>
        /// <param name="notification">The notification</param>
        /// <param name="cancellationToken">Cancellation token</param>
        public async Task Handle(OrderSendBackResultNotify notification, CancellationToken cancellationToken)
        {
            var dto = notification.OrderSendBackResultDto;
            //验证是否存在退回
            var sendBack = await _orderSendBackRepository.GetAsync(dto.Id, cancellationToken);
            if (sendBack is null)
                throw UserFriendlyException.SameMessage("无效退回");

            _mapper.Map(dto, sendBack);
            sendBack.Result = dto.Result;
            sendBack.Reason = dto.Reason;
            await _orderSendBackRepository.UpdateAsync(sendBack, cancellationToken);
            var order = await _orderRepository.GetAsync(sendBack.OrderId, cancellationToken);
            order.Status = EOrderStatus.WaitForAccept;
            await _orderRepository.UpdateAsync(order, cancellationToken);
        }
    }
}
