﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Hotline.DataSharing.Province.Notifications;
using Hotline.Orders;
using MediatR;
using Microsoft.AspNetCore.Http;
using XF.Domain.Repository;

namespace Hotline.Application.Handlers.Order
{
    public class ProvinceOrderUrgeNotifyHandler : INotificationHandler<ProvinceOrderUrgeNotify>
    {
        private readonly IOrderRepository _orderRepository;
        private readonly IRepository<OrderUrge> _orderUrgeRepository;

        public ProvinceOrderUrgeNotifyHandler(
            IOrderRepository orderRepository,
            IRepository<OrderUrge> orderUrgeRepository)
        {
            _orderRepository = orderRepository;
            _orderUrgeRepository = orderUrgeRepository;
        }

        /// <summary>Handles a notification</summary>
        /// <param name="notification">The notification</param>
        /// <param name="cancellationToken">Cancellation token</param>
        public async Task Handle(ProvinceOrderUrgeNotify notification, CancellationToken cancellationToken)
        {
            var dto = notification.ProvinceOrderUrgeDto;
            var order = await _orderRepository.Queryable().Where(x => x.ProvinceNo == dto.CaseSerial).FirstAsync();
            var model = new OrderUrge
            {
                OrderId = order.Id,
                ApplyContent = dto.RemindReasion,
                CrUser = dto.RemindName,
                State = 0,
                CreationTime = dto.RemindTime
            };
            await _orderUrgeRepository.AddAsync(model, cancellationToken);
        }
    }
}
