﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Hotline.DataSharing.Province.Notifications;
using Hotline.Orders;
using MapsterMapper;
using MediatR;
using Microsoft.AspNetCore.Http;
using XF.Domain.Exceptions;

namespace Hotline.Application.Handlers.Order
{
    public class ReceiveOrderExtensionNotifyHandler : INotificationHandler<ReceiveOrderExtensionNotify>
    {
        private readonly IOrderRepository _orderRepository;
        private readonly IOrderDomainService _orderDomainService;
        private readonly IMapper _mapper;

        public ReceiveOrderExtensionNotifyHandler(
            IOrderRepository orderRepository,
            IOrderDomainService orderDomainService,
            IMapper mapper)
        {
            _orderRepository = orderRepository;
            _orderDomainService = orderDomainService;
            _mapper = mapper;
        }

        /// <summary>Handles a notification</summary>
        /// <param name="notification">The notification</param>
        /// <param name="cancellationToken">Cancellation token</param>
        public async Task Handle(ReceiveOrderExtensionNotify notification, CancellationToken cancellationToken)
        {
            var dto = notification.OrderExtensionDto;
            if (string.IsNullOrEmpty(dto.ProvinceNo))
                throw new UserFriendlyException("无效省工单编号");

            var orderExtension = await _orderDomainService.GetOrderExtensionsAsync(dto.ProvinceNo, cancellationToken);
            if (orderExtension is not null) return;

            var extension = _mapper.Map<OrderExtension>(dto);
            var order = await _orderRepository.GetAsync(d => d.ProvinceNo == dto.ProvinceNo, cancellationToken);
            if (order is null)
            {
                await _orderDomainService.AddExtensionAsync(extension, cancellationToken);
            }
            else
            {
                order.OrderExtension = extension;
                await _orderRepository.UpdateNav(order).Include(d => d.OrderExtension).ExecuteCommandAsync();
            }

        }
    }
}
