﻿using Hotline.Share.Dtos.File;
using Hotline.Share.Enums.Order;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using XF.Utility.EnumExtensions;

namespace Hotline.Share.Dtos.Order
{
	public class OrderScreenDto
	{
		/// <summary>
		/// 工单编号
		/// </summary>
		public string No { get; set; }

		/// <summary>
		/// 回访id
		/// </summary>
		public string VisitId { get; set; }

		/// <summary>
		/// 回访明细id
		/// </summary>
		public string VisitDetailId { get; set; }

		/// <summary>
		/// 工单id
		/// </summary>
		public string OrderId { get; set; }

		/// <summary>
		/// 甄别申请类型id
		/// </summary>
		public string TypeDicId { get; set; }

		/// <summary>
		/// 甄别申请类型名称
		/// </summary>
		public string TypeDicName { get; set; }


		/// <summary>
		/// 甄别申请原因
		/// </summary>
		public string Content { get; set; }

		/// <summary>
		/// 甄别申请回复
		/// </summary>
		public string? ReplyContent { get; set; }

		/// <summary>
		/// 甄别申请状态
		/// </summary>
		public EScreenStatus? Status { get; set; }

		/// <summary>
		/// 甄别截至申请时间
		/// </summary>
		public DateTime? ApplyEndTime { get; set; }

		/// <summary>
		/// 附件列表
		/// </summary>
		public List<FileDto> Files { get; set; } = new();

		public List<FileJson>? FileJson { get; set; }
	}

	public class OrderScreenListDto
	{
		/// <summary>
		/// 是否可办理
		/// </summary>
		public bool IsCanHandle { get; set; }

		/// <summary>
		/// 工单编号
		/// </summary>
		public string No { get; set; }

		/// <summary>
		/// 工单id
		/// </summary>
		public string VisitId { get; set; }

		/// <summary>
		/// 工单id
		/// </summary>
		public string OrderId { get; set; }

		/// <summary>
		/// 回访
		/// </summary>
		public OrderVisitDto Visit { get; set; }

		/// <summary>
		/// 工单
		/// </summary>
		public OrderDto Order { get; set; }

		/// <summary>
		/// 回访明细id
		/// </summary>
		public string VisitDetailId { get; set; }

		/// <summary>
		/// 回访
		/// </summary>
		public OrderVisitDetailDto VisitDetail { get; set; }

		/// <summary>
		/// 甄别申请类型id
		/// </summary>
		public string? TypeDicId { get; set; }

		/// <summary>
		/// 甄别申请类型名称
		/// </summary>
		public string? TypeDicName { get; set; }


		/// <summary>
		/// 甄别申请原因
		/// </summary>
		public string? Content { get; set; }

		/// <summary>
		/// 甄别申请回复
		/// </summary>
		public string? ReplyContent { get; set; }


		/// <summary>
		/// 甄别截至申请时间
		/// </summary>
		public DateTime? ApplyEndTime { get; set; }

		/// <summary>
		/// 甄别申请状态
		/// </summary>
		public EScreenStatus? Status { get; set; }

		public string StatusText => Status.GetDescription();

		public DateTime? LastModificationTime { get; set; }

		public bool IsDeleted { get; set; }

		/// <summary>
		/// 删除时间
		/// </summary>
		public DateTime? DeletionTime { get; set; }


		/// <summary>
		/// 创建时间
		/// </summary>
		public DateTime CreationTime { get; set; }

		public string Id { get; set; }

		/// <summary>
		/// 组织Id
		/// </summary>
		public string? CreatorOrgId { get; set; }


		public string? CreatorOrgName { get; set; }

		/// <summary>
		/// 创建人
		/// </summary>
		public string? CreatorId { get; set; }

		public string? CreatorName { get; set; }

		/// <summary>
		/// 业务流程ID
		/// </summary>
		public string? WorkflowId { get; set; }

		/// <summary>
		/// 附件
		/// </summary>
		public List<FileJson>? FileJson { get; set; } = new();

		public List<FileDto> Files { get; set; }
	}

	public class PublishScreenDto {
		// <summary>
		/// 工单对象
		/// </summary>
		public OrderDto Order { get; set; }

		/// <summary>
		/// 甄别
		/// </summary>
		public OrderScreenListDto Screen { get; set; }

		/// <summary>
		/// 附件
		/// </summary>
		public string ClientGuid { get; set; }
	}
	public class ProvinceScreenResult
	{
		/// <summary>
		/// 省工单编号
		/// </summary>
		public string CaseSerial { get; set; }

		/// <summary>
		/// 审核结果是否通过
		/// </summary>
		public string AuditResult { get; set; }

		/// <summary>
		/// 审核意见
		/// </summary>
		public string AuditOpinion { get; set; }

		/// <summary>
		/// 审核时间
		/// </summary>
		public DateTime AuditTime { get; set; }

		/// <summary>
		/// 审核部门
		/// </summary>
		public string AuditOuname { get; set; }

		/// <summary>
		/// 审核人
		/// </summary>
		public string AuditPerson { get; set; }

		/// <summary>
		/// 行政区划代码
		/// </summary>
		public string AreaCode { get; set; }

		/// <summary>
		/// 材料标识
		/// </summary>
		public string CliengGuid { get; set; }
	}
}
