﻿using Hotline.Share.Dtos.File;
using Hotline.Share.Enums.Order;
using Hotline.Share.Enums.Settings;
using Hotline.Share.Requests;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Hotline.Share.Dtos.FlowEngine.Workflow;
using XF.Utility.EnumExtensions;
using Hotline.Share.Enums.FlowEngine;

namespace Hotline.Share.Dtos.Order
{
	public class OrderSpecialAddDto
	{
		public string OrderId { get; set; }

		public string WorkflowId { get; set; }

		/// <summary>
		/// 下一节点code(defineStep.code)
		/// </summary>
		public string NextStepCode { get; set; } = string.Empty;
		public string NextStepName { get; set; } = string.Empty;

		/// <summary>
		/// 根据办理者类型不同，此字段为不同内容
		/// <example>
		/// 部门等级/分类为：depCodes, 角色为：userIds
		/// </example>
		/// </summary>
		public List<Kv> NextHandlers { get; set; } = new();

		/// <summary>
		/// 特提原因
		/// </summary>
		public string? Cause { get; set; }

		/// <summary>
		/// 特提理由
		/// </summary>
		public string? Reason { get; set; }

		/// <summary>
		/// 是否审批
		/// </summary>
		public bool Audit { get; set; } = false;

		/// <summary>
		/// 办理时间限制(如：24小时、7个工作日)
		/// </summary>
		public int? TimeLimit { get; set; }

		public ETimeType? TimeLimitUnit { get; set; } = ETimeType.WorkDay;

		/// <summary>
		/// 是否修改期满时间
		/// </summary>
		public bool AlterTime { get; set; }

		/// <summary>
		/// 附件列表
		/// </summary>
		public List<FileDto> Files { get; set; } = new();

	}
	public class AuditOrderSpecialDto
	{
		public string Id { get; set; }

		public string WorkflowId { get; set; }

		/// <summary>
		/// 下一节点code(defineStep.code)
		/// </summary>
		public string NextStepCode { get; set; } = string.Empty;
		public string NextStepName { get; set; } = string.Empty;

		/// <summary>
		/// 根据办理者类型不同，此字段为不同内容
		/// <example>
		/// 部门等级/分类为：depCodes, 角色为：userIds
		/// </example>
		/// </summary>
		public List<Kv> NextHandlers { get; set; } = new();

		public string? OrgId { get; set; }

		public string? OrgName { get; set; }

		/// <summary>
		///  审核结果  0  待审核  1 审核通过  2 审核不通过
		/// </summary>
		public int State { get; set; }

		/// <summary>
		/// 办理时间限制(如：24小时、7个工作日)
		/// </summary>
		public int? TimeLimit { get; set; }

		public ETimeType? TimeLimitUnit { get; set; } = ETimeType.WorkDay;

		/// <summary>
		/// 特提原因
		/// </summary>
		public string? Cause { get; set; }

		/// <summary>
		/// 特提意见
		/// </summary>
		public string? Opinion { get; set; }

		/// <summary>
		/// 是否修改期满时间
		/// </summary>
		public bool AlterTime { get; set; }

		/// <summary>
		/// 附件列表
		/// </summary>
		public List<FileDto> Files { get; set; } = new();

	}
	public class OrderSpecialDto : OrderSpecialBaseDto
	{

		public string OrderId { get; set; }

		public string WorkflowId { get; set; }

		/// <summary>
		/// 下一节点code(defineStep.code)
		/// </summary>
		public string NextStepCode { get; set; } = string.Empty;
		public string NextStepName { get; set; } = string.Empty;

		public List<Kv> NextHandlers { get; set; }

		/// <summary>
		/// 特提原因
		/// </summary>
		public string? Cause { get; set; }

		/// <summary>
		/// 特提理由
		/// </summary>
		public string? Reason { get; set; }

		/// <summary>
		/// 发送短信
		/// </summary>
		public bool? AcceptSms { get; set; }

		/// <summary>
		/// 办理时间限制(如：24小时、7个工作日)
		/// </summary>
		public int? TimeLimit { get; set; }

		public ETimeType? TimeLimitUnit { get; set; } = ETimeType.WorkDay;

		public string TimeLimitUnitText => TimeLimitUnit.GetDescription();

		/// <summary>
		/// 特提意见
		/// </summary>
		public string? Opinion { get; set; }

		/// <summary>
		///  审核结果  0  待审核  1 审核通过  2 审核不通过
		/// </summary>
		public int State { get; set; }

		public string StateText => State == 0 ? "待审核" : State == 1 ? "审核通过" : State == 2 ? "审核不通过" : "-";

		public string? OrgId { get; set; }

		public string? OrgName { get; set; }


		/// <summary>
		/// 特提节点
		/// </summary>
		public WorkflowTraceDto Trace { get; set; }

		/// <summary>
		/// 工单
		/// </summary>
		public OrderDto Order { get; set; }

		/// <summary>
		/// 附件列表
		/// </summary>
		public List<FileDto> Files { get; set; } = new();

		public List<FileJson> FileJson { get; set; } = new();
	}
	public class OrderSpecialBaseDto
	{
		public DateTime? LastModificationTime { get; set; }

		public bool IsDeleted { get; set; }

		/// <summary>
		/// 删除时间
		/// </summary>
		public DateTime? DeletionTime { get; set; }


		/// <summary>
		/// 创建时间
		/// </summary>
		public DateTime CreationTime { get; set; }

		public string Id { get; set; }

		/// <summary>
		/// 组织Id
		/// </summary>
		public string? CreatorOrgId { get; set; }


		public string? CreatorOrgName { get; set; }

		/// <summary>
		/// 创建人
		/// </summary>
		public string? CreatorId { get; set; }

		public string? CreatorName { get; set; }
	}
	public record OrderSpecialListDto : PagedKeywordRequest
	{
		public DateTime? StartTime { get; set; }
		public DateTime? EndTime { get; set; }

		/// <summary>
		///  审核结果  0  待审核  1 审核通过  2 审核不通过
		/// </summary>
		public int? State { get; set; }

		public string? Cause { get; set; }
	}
	public class OrderSpecialHandleTime 
	{
		public string OrderId { get; set; }

		/// <summary>
		/// 流转方向
		/// </summary>
		public EFlowDirection? FlowDirection { get; set; }
	}
	public class PublishSpecialDto
	{

		/// <summary>
		/// 工单对象
		/// </summary>
		public OrderDto Order { get; set; }

		public OrderSpecialDto Special { get; set; }
	}
}
