﻿// Copyright (c) 2018 Jon P Smith, GitHub: JonPSmith, web: http://www.thereformedprogrammer.net/
// Licensed under MIT license. See License.txt in the project root for license information.

using System.ComponentModel.DataAnnotations;
using System.Diagnostics;

namespace Hotline.Permissions
{
    public enum EPermission
    {
        NotSet = 0, //error condition

        //Here is an example of very detailed control over something
        /// <summary>
        /// 首页
        /// </summary>
        [Display(GroupName = "首页", Name = "首页", Description = "首页")]
        Home = 000000,
        /// <summary>
        /// 坐席首页
        /// </summary>
        [Display(GroupName = "首页",Name ="坐席首页",Description = "坐席首席")]
        HomeSeat = 000001,
        /// <summary>
        /// 部门首页
        /// </summary>
        [Display(GroupName ="首页",Name ="部门首页",Description ="部门首页")]
        HomeOrg = 000002,
        #region 业务待办（10,00,00）
        /// <summary>
        /// 业务待办
        /// </summary>
        [Display(GroupName = "业务待办", Name = "业务待办",Description = "业务待办")]
        BusTodo = 100000,

        #region 工单坐席待办
        /// <summary>
        /// 工单坐席待办
        /// </summary>
        [Display(GroupName = "工单坐席待办",Name = "工单坐席待办",Description = "工单坐席待办")]
        OrderSeatTodo = 100100,

        /// <summary>
        /// 新建工单
        /// </summary>
        [Display(GroupName = "Order", Name = "新建工单", Description = "新建工单")]
        OrderAdd = 100101,
        /// <summary>
        /// 工单签收
        /// </summary>
        [Display(GroupName = "工单坐席待办",Name ="工单签收",Description ="工单签收")]
        OrderSign = 100102,
        /// <summary>
        /// 工单修改
        /// </summary>
        [Display(GroupName = "工单坐席待办",Name ="工单修改",Description ="工单修改")]
        OrderEdit = 100103,
        #endregion

        #region 工单待办
        /// <summary>
        /// 工单待办
        /// </summary>
        [Display(GroupName = "工单待办",Name = "工单待办",Description = "工单待办")]
        OrderToDo = 100200,

        /// <summary>
        /// 退回申请
        /// </summary>
        [Display(GroupName = "OrderSendBack", Name = "退回申请", Description = "退回申请")]
        ApplySendBack = 100201,
        #endregion

        #region 发布待办
        /// <summary>
        /// 发布待办
        /// </summary>
        [Display(GroupName = "发布待办",Name ="发布待办",Description = "发布待办")]
        PublishTodo = 100300,

        /// <summary>
        /// 发布工单
        /// </summary>
        [Display(GroupName = "发布待办", Name = "发布工单", Description = "发布工单")]
        PublishOrder = 100301,

        #endregion

        #region 回访待办
        /// <summary>
        /// 回访待办
        /// </summary>
        [Display(GroupName = "回访待办",Name ="回访待办",Description = "回访待办")]
        VisitTodo = 100400,

        /// <summary>
        /// 回访
        /// </summary>
        [Display(GroupName = "回访待办", Name = "回访", Description = "回访")]
        Visit = 100401,
        /// <summary>
        /// 短信回访
        /// </summary>
        [Display(GroupName ="回访待办",Name ="短信回访",Description ="短信回访")]
        MessageVisit = 100402,
        /// <summary>
        /// 智能回访
        /// </summary>
        [Display(GroupName ="回访待办",Name = "智能回访",Description ="智能回访")]
        AiVisit = 100403,
        /// <summary>
        /// 分配回访人
        /// </summary>
        [Display(GroupName = "回访待办",Name ="分配回访人",Description = "分配回访人")]
        MultiplePeople = 100404,
        #endregion

        #region 延期待办
        /// <summary>
        /// 延期待办
        /// </summary>
        [Display(GroupName = "延期待办",Name = "延期待办",Description = "延期待办")]
        DelayOrder = 100500,
        /// <summary>
        /// 延期审核
        /// </summary>
        [Display(GroupName ="延期待办",Name ="延期审核",Description ="延期审核")]
        DelayOrderAudit = 100501,
        /// <summary>
        /// 延期退回
        /// </summary>
        [Display(GroupName ="延期待办",Name = "延期退回",Description ="延期退回")]
        DelayOrderReturn = 100502,
        #endregion

        #region 甄别待办
        /// <summary>
        /// 甄别待办
        /// </summary>
        [Display(GroupName ="甄别待办",Name ="甄别待办",Description ="甄别待办")]
        ScreenOrder = 100600,
        /// <summary>
        /// 甄别审批
        /// </summary>
        [Display(GroupName = "甄别待办", Name ="甄别审批",Description ="甄别审批")]
        ScreenOrderAudit = 100601,
        /// <summary>
        /// 甄别退回
        /// </summary>
        [Display(GroupName = "甄别待办",Name ="甄别退回",Description ="甄别退回")]
        ScreenOrderReturn = 100602,
        #endregion

        #region 督办待办
        /// <summary>
        /// 督办待办
        /// </summary>
        [Display(GroupName ="督办待办",Name ="督办待办",Description ="督办待办")]
        OrderSupervise = 100700,

        SuperviseOrderReply = 100701,
        #endregion

        #region 退回待办
        /// <summary>
        /// 退回待办
        /// </summary>
        [Display(GroupName = "退回待办",Name ="退回待办",Description ="退回待办")]
        OrderSendBack = 100800,

        /// <summary>
		/// 退回审核
		/// </summary>
		[Display(GroupName = "退回申请", Name = "退回审核", Description = "退回审核")]
        SendBackAudit = 100801,
        #endregion

        #region 催办待办
        /// <summary>
        /// 催办待办
        /// </summary>
        [Display(GroupName = "催办待办",Name ="催办待办",Description = "催办待办")]
        OrderUrging = 100900,
        /// <summary>
        /// 催办签收
        /// </summary>
        [Display(GroupName = "催办待办",Name ="催办签收",Description ="催办签收")]
        OrderUrgingSign = 100902,

        #endregion
        #endregion

        #region 业务管理（20,00,00）
        /// <summary>
        /// 业务管理
        /// </summary>
        [Display(GroupName = "业务管理",Name ="业务管理",Description = "业务管理")]
        BugManage = 200000,

        #region 工单列表
        /// <summary>
        /// 工单列表
        /// </summary>
        [Display(GroupName = "工单列表",Name = "工单列表",Description = "工单列表")]
        OrderList = 200100,

        /// <summary>
        /// 查询工单
        /// </summary>
        [Display(GroupName = "工单列表", Name = "查询工单列表", Description = "查询工单列表")]
        OrderQuery = 200101,

        /// <summary>
		/// 新增工单观察
		/// </summary>
		[Display(GroupName = "工单列表", Name = "新增工单观察", Description = "新增工单观察")]
        AddOrderObserve = 200102,

        /// <summary>
		/// 新增工单终结
		/// </summary>
		[Display(GroupName = "工单列表", Name = "新增工单终结", Description = "新增工单终结")]
        AddOrderFinality = 200103,

        /// <summary>
        /// 编辑工单
        /// </summary>
        [Display(GroupName = "工单列表", Name = "编辑工单", Description = "编辑工单")]
        OrderUpdate = 200104,
        /// <summary>
        /// 工单导出
        /// </summary>
        [Display(GroupName = "工单列表",Name ="工单导出",Description ="工单导出")]
        OrderExport = 200105,

        /// <summary>
        /// 工单延期
        /// </summary>
        [Display(GroupName = "工单列表", Name = "申请延期", Description = "申请延期")]
        ApplyDelay = 200106,
        /// <summary>
        /// 工单办理
        /// </summary>
        [Display(GroupName = "工单列表",Name ="工单办理",Description ="工单办理")]
        HandleOrder = 200107,

        /// <summary>
		/// 申请督办
		/// </summary>
		[Display(GroupName = "工单列表", Name = "申请督办", Description = "申请督办")]
        ApplySupervise = 200108,

        /// <summary>
		/// 申请催办
		/// </summary>
		[Display(GroupName = "工单列表", Name = "申请催办", Description = "申请催办")]
        ApplyUrge = 200109,
        /// <summary>
        /// 工单退回
        /// </summary>
        [Display(GroupName ="工单列表",Name ="工单退回",Description = "工单退回")]
        ReturnOrder = 200110,

        /// <summary>
		/// 特提申请
		/// </summary>
		[Display(GroupName = "工单列表", Name = "特提申请", Description = "特提申请")]
        ApplySpecial = 200111,
        /// <summary>
        /// 会签结束
        /// </summary>
        [Display(GroupName = "工单列表",Name ="会签结束",Description ="会签结束")]
        CloseCountersignature = 200112,
        #endregion

        #region 发布列表
        [Display(GroupName = "业务管理",Name ="发布列表",Description = "发布列表")]
        PublishedOrder = 200200,

        /// <summary>
        /// 已发布列表
        /// </summary>
        [Display(GroupName = "业务管理", Name = "已发布列表", Description = "已发布列表")]
        PublishedOrderList = 200201,

        /// <summary>
        /// 修改发布
        /// </summary>
        [Display(GroupName = "OrderPublish", Name = "修改发布", Description = "修改发布")]
        PublishedModify = 200202,
        #endregion

        #region 回访列表
        [Display(GroupName = "业务管理",Name ="回访列表",Description ="回访列表")]
        OrderVisited = 200300,

        #endregion

        #region 延期列表
        /// <summary>
        /// 延期列表
        /// </summary>
        [Display(GroupName = "业务管理",Name ="延期列表",Description = "延期列表")]
        DelaiedOrder = 200400,
        /// <summary>
        /// 延期审批
        /// </summary>
        [Display(GroupName ="业务管理",Name = "延期审批", Description = "延期审批")]
        DelaiedOrderAudit = 200401,
        /// <summary>
        /// 延期撤销
        /// </summary>
        [Display(GroupName = "业务管理",Name ="延期撤销",Description = "延期撤销")]
        DelaiedOrderRevoke = 200402,
        /// <summary>
        /// 延期退回
        /// </summary>
        [Display(GroupName = "业务管理",Name ="延期退回",Description ="延期退回")]
        DelaiedOrderReturn = 200403,
        #endregion

        #region 甄别列表
        /// <summary>
        /// 甄别列表
        /// </summary>
        [Display(GroupName = "业务管理",Name ="甄别列表",Description = "甄别列表")]
        OrderScreen = 200500,
        /// <summary>
        /// 甄别审批
        /// </summary>
        [Display(GroupName = "业务管理",Name ="甄别审批",Description ="甄别审批")]
        OrderScreenAudit = 200501,
        /// <summary>
        /// 甄别导出
        /// </summary>
        [Display(GroupName = "业务管理",Name = "甄别导出",Description ="甄别导出")]
        OrderScreenExport = 200502,
        /// <summary>
        /// 甄别退回
        /// </summary>
        [Display(GroupName ="业务管理",Name ="甄别退回",Description ="甄别退回")]
        OrderScreenReturn = 200503,
        #endregion

        #region 甄别待申请
        /// <summary>
        /// 待甄别列表
        /// </summary>
        [Display(GroupName = "业务管理",Name ="待甄别列表",Description ="待甄别列表")]
        CanOrderScreen = 200600,
        /// <summary>
		/// 工单甄别列表
		/// </summary>
		[Display(GroupName = "业务管理", Name = "工单甄别待申请列表", Description = "工单甄别待申请列表")]
        MayOrderScreenList = 200601,
        /// <summary>
        /// 申请甄别
        /// </summary>
        [Display(GroupName = "业务管理", Name = "申请甄别", Description = "申请甄别")]
        ApplyScreen = 200602,
        #endregion

        #region 督办列表
        /// <summary>
        /// 督办列表
        /// </summary>
        [Display(GroupName = "业务管理",Name ="督办列表",Description ="督办列表")]
        SuperviseOrder = 200700,
        /// <summary>
        /// 回复督办
        /// </summary>
		[Display(GroupName = "OrderSupervise", Name = "回复督办", Description = "回复督办")]
        ReplySuperviseOrder = 200701,
		#endregion

		#region 省退回申请
		/// <summary>
		/// 省退回申请
		/// </summary>
		[Display(GroupName = "省退回申请",Name ="省退回申请",Description ="省退回申请")]
        SendBackOrder = 200800,

        /// <summary>
        ///工单退回列表
        /// </summary>
        [Display(GroupName = "省退回申请", Name = "工单退回列表", Description = "工单退回列表")]
        SendBackOrderList = 200801,

        /// <summary>
		/// 退回审核
		/// </summary>
		[Display(GroupName = "省退回申请", Name = "退回审核", Description = "退回审核")]
        AuditSendBack = 200802,
        #endregion

        #region 市民画像管理
        /// <summary>
        /// 市民画像管理
        /// </summary>
        [Display(GroupName = "市民画像管理",Name ="市民画像管理",Description ="市民画像管理")]
        Citizen  = 200900,

        /// <summary>
		/// 市民信息列表
		/// </summary>
		[Display(GroupName = "市民画像管理", Name = "市民信息列表", Description = "市民信息列表")]
        CitizenList = 200901,

        /// <summary>
        /// 新增市民信息
        /// </summary>
        [Display(GroupName = "市民画像管理", Name = "新增市民信息", Description = "新增市民信息")]
        AddCitizen = 200902,

        /// <summary>
        /// 删除市民信息
        /// </summary>
        [Display(GroupName = "市民画像管理", Name = "删除市民信息", Description = "删除市民信息")]
        DeleteCitizen = 200903,

        /// <summary>
        /// 修改市民信息
        /// </summary>
        [Display(GroupName = "市民画像管理", Name = "修改市民信息", Description = "修改市民信息")]
        UpdateCitizen = 200904,

        /// <summary>
        /// 市民画像标签记录
        /// </summary>
        [Display(GroupName ="市民画像管理",Name ="市民画像标签记录",Description = "市民画像标签记录")]
        CitizenTag = 200905,

        #endregion

        #region 重复性事件管理
        /// <summary>
        /// 重复性事件管理
        /// </summary>
        [Display(GroupName = "重复性事件管理",Name ="重复性事件管理",Description ="重复性事件管理")]
        RepeatableEvent = 200900,

        /// <summary>
		/// 重复性事件列表
		/// </summary>
		[Display(GroupName = "RepeatableEvent", Name = "重复性事件列表", Description = "重复性事件列表")]
        RepeatableEventList = 200901,

        /// <summary>
        /// 修改重复性事件
        /// </summary>
        [Display(GroupName = "RepeatableEvent", Name = "修改重复性事件", Description = "修改重复性事件")]
        UpdateRepeatableEvent = 200902,


        #endregion

        #region 二次回访申请
        [Display(GroupName = "二次回访申请",Name ="二次回访申请")]
        OrderVisitAgain = 201000,

        /// <summary>
        /// 可申请二次回访列表
        /// </summary>
        [Display(GroupName = "二次回访申请", Name = "可申请二次回访列表", Description = "可申请二次回访列表")]
        OrderVisitAgainList = 201001,

        /// <summary>
        /// 申请二次回访
        /// </summary>
        [Display(GroupName = "二次回访申请", Name = "申请二次回访", Description = "申请二次回访")]
        ApplyOrderVisit = 201002,
        #endregion

        #region 二次回访审核
        /// <summary>
        /// 二次回访审核
        /// </summary>
        [Display(GroupName = "二次回访审核",Name = "二次回访审核",Description ="二次回访审核")]
        VisitApply  = 201100,

        /// <summary>
        /// 二次回访申请列表
        /// </summary>
        [Display(GroupName = "二次回访审核", Name = "二次回访申请列表", Description = "二次回访申请列表")]
        VisitApplyList = 201101,

        /// <summary>
        /// 审核二次回访
        /// </summary>
        [Display(GroupName = "ExaminOrderVisit", Name = "二次回访审核", Description = "二次回访审核")]
        ExaminOrderVisit = 201102,
        #endregion

        #region 特提申请
        /// <summary>
        /// 特提申请
        /// </summary>
        [Display(GroupName = "特提申请",Name ="特提申请",Description ="特提申请")]
        SpecialOrder = 201200,

        /// <summary>
		///工单特提列表
		/// </summary>
		[Display(GroupName = "OrderSpecial", Name = "工单特提列表", Description = "工单特提列表")]
        SpecialOrderList = 201201,

        /// <summary>
		/// 特提申请
		/// </summary>
		[Display(GroupName = "特提申请", Name = "特提申请", Description = "特提申请")]
        ApplySpecialOrder = 201202,
        #endregion

        #region 特提审批
        /// <summary>
        /// 特提审核
        /// </summary>
        [Display(GroupName = "特提审核",Name ="特提审核",Description ="特提审核")]
        SpecialOrderApply = 201300,

        /// <summary>
		///工单特提申请列表
		/// </summary>
		[Display(GroupName = "特提审核", Name = "工单特提申请列表", Description = "工单特提申请列表")]
        ApplySpecialOrderList = 201301,

        /// <summary>
		/// 特提审核
		/// </summary>
		[Display(GroupName = "特提审核", Name = "特提审核", Description = "特提审核")]
        AuditSpecial = 201302,

		#region 业务退回审批
		/// <summary>
		///工单业务退回审批列表
		/// </summary>
		[Display(GroupName = "业务退回审批", Name = "工单业务退回审批列表", Description = "工单业务退回审批列表")]
		OrderPreviousList = 201401,

		/// <summary>
		/// 工单业务退回审批
		/// </summary>
		[Display(GroupName = "业务退回审批", Name = "业务退回审批", Description = "业务退回审批")]
		OrderPreviousAudit = 204302,
		#endregion
		#endregion
		#endregion

		#region 业务查询（30,00,00）
		/// <summary>
		/// 业务查询
		/// </summary>
		[Display(GroupName = "业务查询",Name ="业务查询",Description = "业务查询")]
        BugQuery = 300000,

        #region 观察件查询
        /// <summary>
        /// 观察件查询
        /// </summary>
        [Display(GroupName = "业务查询",Name ="观察件查询")]
        OrderObserve =  300100,

        #endregion

        #region 终结件查询
        /// <summary>
        /// 工单终结列表
        /// </summary>
        [Display(GroupName = "业务查询", Name = "工单终结查询", Description = "工单终结查询")]
        OrderFinality = 300200,

        #endregion

        #region 催办查询
        /// <summary>
        /// 催办查询
        /// </summary>
        [Display(GroupName = "业务查询",Name = "催办查询",Description = "催办查询")]
        UrgeOrder = 300300,
        
        #endregion

        #region 会签查询
        /// <summary>
        /// 会签查询
        /// </summary>
        [Display(GroupName = "会签查询",Name ="会签查询",Description ="会签查询")]
        CounterSign = 300400,

        #endregion

        #region 工单即将超期
        /// <summary>
        /// 工单即将超期
        /// </summary>
        [Display(GroupName ="工单即将超期",Name ="工单即将超期",Description = "工单即将超期")]
        OverdueSoonOrder = 300500,

        #endregion

        #region 工单超期列表
        /// <summary>
        /// 工单超期列表
        /// </summary>
        [Display(GroupName = "工单超期列表",Name ="工单超期列表",Description = "工单超期列表")]
        OverdueOrder = 300600,

        #endregion

        #endregion

        #region 质检管理（40,00,00）
        /// <summary>
        /// 质检管理
        /// </summary>
        [Display(GroupName = "质检管理",Name ="质检管理",Description ="质检管理")]
        QualityManage = 400000,

        #region 质检中心
        /// <summary>
        /// 质检中心
        /// </summary>
        [Display(GroupName = "质检管理",Name = "质检中心",Description = "质检中心")]
        QualityCenter = 400100,

        /// <summary>
        /// 工单详情
        /// </summary>
        [Display(GroupName = "质检中心",Name ="工单详情",Description = "工单详情")]
        OrderInfo = 400101,
        /// <summary>
        /// 质检
        /// </summary>
        [Display(GroupName = "质检",Name = "质检",Description ="质检")]
        QualityOrder = 400102,

        #endregion

        #region 已质检列表
        /// <summary>
        /// 已质检列表
        /// </summary>
        [Display(GroupName = "已质检列表",Name = "已质检列表",Description ="已质检列表")]
        QualitiedList = 400200,
        /// <summary>
        /// 质检查看
        /// </summary>
        [Display(GroupName = "已质检列表",Name ="质检查看",Description = "质检查看")]
        QualitieyInfo = 400201,
        /// <summary>
        /// 修改质检
        /// </summary>
        [Display(GroupName = "已质检列表", Name = "修改质检", Description = "修改质检")]
        UpdateQuality = 400104,
        #endregion

        #region 质检项目管理
        /// <summary>
        /// 质检项目管理
        /// </summary>
        [Display(GroupName = "质检项目管理",Name ="质检项目管理",Description = "质检项目管理")]
        QualityItem = 400300,
        /// <summary>
        /// 质检项目列表
        /// </summary>
        [Display(GroupName = "质检项目管理", Name = "质检项目列表", Description = "质检项目列表")]
        QualityItemList = 400301,

        /// <summary>
        /// 新增质检项目
        /// </summary>
        [Display(GroupName = "QualityItem", Name = "新增质检项目", Description = "新增质检项目")]
        AddQualityItem = 400302,

        /// <summary>
        /// 删除质检项目
        /// </summary>
        [Display(GroupName = "QualityItem", Name = "删除质检项目", Description = "删除质检项目")]
        DeleteQualityItem = 400303,

        /// <summary>
		/// 修改质检项目
		/// </summary>
		[Display(GroupName = "QualityItem", Name = "修改质检项目", Description = "修改质检项目")]
        UpdateQualityItem = 400304,
        #endregion

        #region 质检模版管理
        /// <summary>
        /// 质检模板管理
        /// </summary>
        [Display(GroupName = "质检模板管理",Name ="质检模板管理",Description ="质检模板管理")]
        QualityTemplate = 400400,
        /// <summary>
        /// 质检模版列表
        /// </summary>
        [Display(GroupName = "QualityTemplate", Name = "质检模版列表", Description = "质检模版列表")]
        QualityTemplateList = 400401,

        /// <summary>
        /// 新增质检模版
        /// </summary>
        [Display(GroupName = "QualityTemplate", Name = "新增质检模版", Description = "新增质检模版")]
        AddQualityTemplate = 400402,

        /// <summary>
        /// 删除质检模版
        /// </summary>
        [Display(GroupName = "QualityTemplate", Name = "删除质检模版", Description = "删除质检模版")]
        DeleteQualityTemplate = 400403,

        /// <summary>
        /// 修改质检模版
        /// </summary>
        [Display(GroupName = "QualityTemplate", Name = "修改质检模版", Description = "修改质检模版")]
        UpdateQualityTemplate = 400404,

        /// <summary>
        /// 启禁用质检模版
        /// </summary>
        [Display(GroupName = "QualityTemplate", Name = "启禁用质检模版", Description = "启禁用质检模版")]
        EnableQualityTemplate = 400405,
        #endregion

        #region 质检违禁词管理
        /// <summary>
        /// 质检违禁词管理
        /// </summary>
        [Display(GroupName = "质检违禁词管理",Name = "质检违禁词管理",Description ="质检违禁词管理")]
        QualityProhibited = 400500,

        /// <summary>
        /// 质检违禁词列表
        /// </summary>
        [Display(GroupName = "QualityProhibited", Name = "质检违禁词列表", Description = "质检违禁词列表")]
        QualityProhibitedList = 400501,

        /// <summary>
        /// 新增质检违禁词
        /// </summary>
        [Display(GroupName = "QualityProhibited", Name = "新增质检违禁词", Description = "新增质检违禁词")]
        AddQualityProhibited = 400502,

        /// <summary>
        /// 删除质检违禁词
        /// </summary>
        [Display(GroupName = "QualityProhibited", Name = "删除质检违禁词", Description = "删除质检违禁词")]
        DeleteQualityProhibited = 400503,

        /// <summary>
        /// 修改质检违禁词
        /// </summary>
        [Display(GroupName = "QualityProhibited", Name = "修改质检违禁词", Description = "修改质检违禁词")]
        UpdateQualityProhibited = 400504,

        #endregion

        #endregion

        #region 智能回访（120000）
        /// <summary>
        /// 智能回访
        /// </summary>
        [Display(GroupName ="智能回访",Name ="智能回访",Description ="智能回访")]
        AiVisitDir = 120000,
        /// <summary>
        /// 智能回访任务
        /// </summary>
        [Display(GroupName ="智能回访",Name ="智能回访任务",Description ="智能回访任务")]
        AiVisitTask = 120100,
        /// <summary>
        /// 新增智能回访任务
        /// </summary>
        [Display(GroupName = "智能回访",Name ="新增智能回访任务",Description ="新增智能回访任务")]
        AddAiVisitTask = 120101,
        #endregion

        #region 系统管理（50,00,00）

        /// <summary>
        /// 系统管理
        /// </summary>
        [Display(GroupName = "系统管理", Name = "系统管理", Description = "系统管理")]
        SystemManage = 500000,

        #region 组织架构
        /// <summary>
        /// 组织架构
        /// </summary>
        [Display(GroupName = "系统管理", Name = "组织架构", Description = "组织架构")]
        OrgManage = 500100,

        /// <summary>
        /// 组织架构树形列表
        /// </summary>
        [Display(GroupName = "系统设置", Name = "组织架构树形列表", Description = "组织架构树形列表")]
        GetOrgJson = 500101,
        /// <summary>
        /// 新增组织
        /// </summary>
        [Display(GroupName = "系统设置", Name = "新增组织", Description = "新增组织")]
        AddOrg = 500102,
        /// <summary>
        /// 修改组织
        /// </summary>
        [Display(GroupName = "系统设置", Name = "修改组织", Description = "修改组织")]
        UpdateOrg = 500103,

        #endregion

        #region 用户管理
        /// <summary>
        /// 用户管理
        /// </summary>
        [Display(GroupName = "系统管理",Name = "用户管理",Description ="用户管理")]
        UserManage = 500200,

        /// <summary>
        /// 分页查询用户
        /// </summary>
        [Display(GroupName = "用户管理", Name = "分页查询用户", Description = "分页查询用户")]
        QueryPagedUser = 500201,
        /// <summary>
        /// 新增用户
        /// </summary>
        [Display(GroupName = "用户管理", Name = "新增用户", Description = "新增用户")]
        AddUser = 500202,
        /// <summary>
        /// 更新用户
        /// </summary>
        [Display(GroupName = "用户管理", Name = "更新用户", Description = "更新用户")]
        UpdateUser = 500203,
        /// <summary>
        /// 删除用户
        /// </summary>
        [Display(GroupName = "用户管理", Name = "删除用户", Description = "删除用户")]
        RemoveUser = 500204,
        /// <summary>
        /// 重置密码
        /// </summary>
        [Display(GroupName ="用户管理",Name ="重置密码",Description ="重置密码")]
        ResetPwd = 500205,
        #endregion

        #region 角色管理
        /// <summary>
        /// 角色管理
        /// </summary>
        [Display(GroupName = "系统管理",Name = "角色管理",Description ="角色管理")]
        RoleManage = 500300,
        /// <summary>
        /// 分页查询角色
        /// </summary>
        [Display(GroupName = "角色管理", Name = "分页查询角色", Description = "分页查询角色")]
        QueryPagedRole = 500301,
        /// <summary>
        /// 新增角色
        /// </summary>
        [Display(GroupName = "角色管理", Name = "新增角色", Description = "新增角色")]
        AddRole = 500302,
        /// <summary>
        /// 删除角色
        /// </summary>
        [Display(GroupName = "角色管理", Name = "删除角色", Description = "删除角色")]
        RemoveRole = 500303,
        /// <summary>
        /// 更新角色
        /// </summary>
        [Display(GroupName = "角色管理", Name = "更新角色", Description = "更新角色")]
        UpdateRole = 500304,
        #region 应用权限管理
        /// <summary>
        /// 分配权限
        /// </summary>
        [Display(GroupName = "角色管理", Name = "分配权限", Description = "分配权限")]
        AllocationAuthority = 500305,
        
        #endregion
        #region 数据权限管理
        /// <summary>
        /// 数据权限
        /// </summary>
        [Display(GroupName = "角色管理", Name = "数据权限", Description = "数据权限")]
        DataAuthorityByRole = 500306,
        
        #endregion
        #endregion

        #region 菜单管理（500400）
        /// <summary>
        /// 菜单管理
        /// </summary>
        [Display(GroupName = "系统设置", Name = "菜单管理", Description = "菜单管理")]
        GetMenuJson = 500400,
        /// <summary>
        /// 新增菜单
        /// </summary>
        [Display(GroupName = "系统设置", Name = "新增菜单", Description = "新增菜单")]
        AddMenu = 500401,
        /// <summary>
        /// 修改菜单
        /// </summary>
        [Display(GroupName = "系统设置", Name = "修改菜单", Description = "修改菜单")]
        UpdateMenu = 500402,
        /// <summary>
        /// 删除菜单
        /// </summary>
        [Display(GroupName = "系统设置", Name = "删除菜单", Description = "删除菜单")]
        RemoveMenu = 500403,
        #endregion

        #region 配置管理
        /// <summary>
        /// 配置管理
        /// </summary>
        [Display(GroupName = "系统设置",Name ="配置管理",Description = "配置管理")]
        ConfigManage = 500500,

        #region 字典管理
        /// <summary>
        /// 字典管理
        /// </summary>
        [Display(GroupName = "配置管理",Name ="字典管理",Description ="字典管理")]
        SysDicManage = 500600,
        /// <summary>
        /// 字典类型列表
        /// </summary>
        [Display(GroupName = "系统设置", Name = "字典类型列表", Description = "字典类型列表")]
        GetSysDicType = 500601,
        /// <summary>
        /// 字典数据列表
        /// </summary>
        [Display(GroupName = "系统设置", Name = "字典数据列表", Description = "字典数据列表")]
        GetSysDicData = 500602,
        /// <summary>
        /// 获取字典对象
        /// </summary>
        [Display(GroupName = "系统设置", Name = "获取字典对象", Description = "获取字典对象")]
        SysDicDataModel = 500603,
        /// <summary>
        /// 新增字典数据
        /// </summary>
        [Display(GroupName = "系统设置", Name = "新增字典数据", Description = "新增字典数据")]
        AddDicData = 500604,
        /// <summary>
        /// 修改字典数据
        /// </summary>
        [Display(GroupName = "系统设置", Name = "修改字典数据", Description = "修改字典数据")]
        UpdateDicData = 500605,

        #endregion

        #region 流程配置
        /// <summary>
        /// 流程配置
        /// </summary>
        [Display(GroupName = "系统设置",Name ="流程配置",Description = "流程配置")]
        FlowManage = 500700,

        /// <summary>
        /// 查询流程模板
        /// </summary>
        [Display(GroupName = "系统设置", Name = "查询流程模板", Description = "查询流程模板")]
        FlowDefinitionQuery = 500701,

        /// <summary>
        /// 新建流程模板
        /// </summary>
        [Display(GroupName = "系统设置", Name = "新建流程模板", Description = "新建流程模板")]
        FlowDefinitionAdd = 500702,

        /// <summary>
        /// 删除流程模板
        /// </summary>
        [Display(GroupName = "系统设置", Name = "删除流程模板", Description = "删除流程模板")]
        FlowDefinitionRemove = 500703,

        /// <summary>
        /// 更新流程模板
        /// </summary>
        [Display(GroupName = "系统设置", Name = "更新流程模板", Description = "更新流程模板")]
        FlowDefinitionUpdate = 500704,

        /// <summary>
        /// 发布流程模板
        /// </summary>
        [Display(GroupName = "系统设置", Name = "发布流程模板", Description = "发布流程模板")]
        FlowDefinitionPublish = 500705,
        /// <summary>
        /// 流程编辑页面
        /// </summary>
        [Display(GroupName = "系统设置",Name ="流程编辑页面",Description ="流程编辑页面")]
        FlowEditPage = 500706,
        /// <summary>
        /// 配置模板
        /// </summary>
        [Display(GroupName ="系统设置",Name = "配置模板",Description = "配置模板")]
        SetDefinition = 500707,
        /// <summary>
        /// 清除配置
        /// </summary>
        [Display(GroupName ="系统设置",Name ="清除配置",Description ="清除配置")]
        ClearSet = 500708,
        #endregion

        #region 节假日设置
        /// <summary>
        /// 工作时间配置
        /// </summary>
        [Display(GroupName = "系统设置",Name ="工作时间配置",Description ="工作时间配置")]
        DaySettings = 500700,

        /// <summary>
        /// 节假日设置列表
        /// </summary>
        [Display(GroupName = "系统设置", Name = "节假日设置", Description = "节假日设置")]
        DaySetingsList = 500701,
        /// <summary>
        /// 设置节假日
        /// </summary>
        [Display(GroupName = "系统设置", Name = "设置节假日", Description = "设置节假日")]
        SetDaySetting = 500702,
        #endregion

        #endregion

        #region 系统参数
        /// <summary>
        /// 系统参数
        /// </summary>
        [Display(GroupName ="系统设置",Name ="系统参数",Description ="系统参数")]
        SysSettings = 500800,
        /// <summary>
        /// 获取系统参数列表
        /// </summary>
        [Display(GroupName = "系统设置", Name = "获取系统参数列表", Description = "获取系统参数列表")]
        GetSysSettings = 500801,
        /// <summary>
        /// 更新设置
        /// </summary>
        [Display(GroupName = "系统设置", Name = "更新设置", Description = "更新设置")]
        ModifySettings = 500802,

        /// <summary>
        /// 获取系统参数对象
        /// </summary>
        [Display(GroupName = "系统设置", Name = "获取系统参数对象", Description = "获取系统参数对象")]
        GetSettingEntity = 500803,

        /// <summary>
        /// 新增系统参数
        /// </summary>
        [Display(GroupName = "系统设置", Name = "新增系统参数", Description = "新增系统参数")]
        AddSetting = 500804,


        #endregion

        #region 系统日志
        /// <summary>
        /// 系统日志
        /// </summary>
        [Display(GroupName = "系统管理",Name ="系统日志",Description = "系统日志")]
        SystemLog = 500900,
        /// <summary>
        /// 日志明细
        /// </summary>
        [Display(GroupName ="系统管理",Name ="日志明细",Description ="日志明细")]
        SystemLogDetail = 500901,

        #endregion
        #endregion

        #region 知识库（60,00,00）
        /// <summary>
        /// 知识库
        /// </summary>
        [Display(GroupName = "知识库", Name = "知识库", Description = "知识库")]
        KnowledgeBase = 600000,

        #region 知识库新增/编辑
        /// <summary>
        /// 知识库新增、编辑
        /// </summary>
        [Display(GroupName = "知识库",Name = "知识库新增、编辑",Description = "知识库新增、编辑")]
        KnowledgeAddOrEditBase = 600100,

        #endregion

        #region 知识库查看
        /// <summary>
        /// 知识库
        /// </summary>
        [Display(GroupName="知识库",Name ="知识库查看",Description ="知识库")]
        KnowledgePreview = 600200,
        #endregion

        #region 知识库管理
        /// <summary>
        /// 知识库管理
        /// </summary>
        [Display(GroupName = "知识库", Name = "知识库管理", Description = "知识库管理")]
        KnowledgeManage = 600300,

        #region 知识库
        /// <summary>
        /// 新增审核按钮
        /// </summary>
        [Display(GroupName = "知识库", Name = "新增审核按钮", Description = "提交审核按钮")]
        AddKnowledge = 600302,
        /// <summary>
        /// 知识库查看
        /// </summary>
        [Display(GroupName ="知识库",Name = "知识库查看",Description ="知识库查看")]
        KnowledgeRead = 600303,

        /// <summary>
        /// 知识修改
        /// </summary>
        [Display(GroupName = "知识库", Name = "知识修改", Description = "知识修改")]
        KnowledgeUpdate = 600304,
        /// <summary>
        /// 知识删除
        /// </summary>
        [Display(GroupName = "知识库管理", Name = "知识删除", Description = "知识删除")]
        KnowledgeDelete = 600305,
        /// <summary>
        /// 知识下架
        /// </summary>
        [Display(GroupName = "知识库管理", Name = "知识下架", Description = "知识下架")]
        KnowledgeOffShelf = 600306,
        /// <summary>
        /// 知识上架
        /// </summary>
        [Display(GroupName = "知识库管理", Name = "知识上架", Description = "知识上架")]
        KnowledgeOnTheShelf = 600307,

        #endregion

        #endregion

        #region 知识检索
        /// <summary>
        /// 知识检索
        /// </summary>
        [Display(GroupName = "知识库", Name = "知识检索", Description = "知识检索")]
        KnowledgeRetrieval = 600400,
        /// <summary>
        /// 知识库检索列表
        /// </summary>
        [Display(GroupName = "知识库",Name ="知识库检索列表",Description ="知识库检索列表")]
        KnowledgeRetrievalList = 600401,
        #endregion

        #region 知识纠错
        /// <summary>
        /// 知识库纠错
        /// </summary>
        [Display(GroupName = "知识库",Name ="知识库纠错",Description = "知识库纠错")]
        KnowledgeCorrection = 600500,

        /// <summary>
        /// 知识纠错列表
        /// </summary>
        [Display(GroupName = "KnowledgeCorrection", Name = "知识纠错列表", Description = "知识纠错列表")]
        KnowledgeCorrectionList = 600501,

        /// <summary>
        /// 知识纠错实体
        /// </summary>
        [Display(GroupName = "KnowledgeCorrection", Name = "知识纠错实体", Description = "知识纠错实体")]
        KnowledgeCorrectionEntity = 600502,

        /// <summary>
        /// 答复知识纠错
        /// </summary>
        [Display(GroupName = "KnowledgeCorrection", Name = "答复知识纠错", Description = "答复知识纠错")]
        ReplyKnowledgeCorrection = 600503,
        #endregion

        #region 知识提问
        /// <summary>
        /// 知识库提问
        /// </summary>
        [Display(GroupName = "知识库",Name ="知识库提问",Description = "知识库提问")]
        KnowledgeQuestions = 600600,

        /// <summary>
        /// 知识提问列表
        /// </summary>
        [Display(GroupName = "知识库", Name = "知识提问列表", Description = "知识提问列表")]
        KnowledgeQuestionsList = 600601,

        /// <summary>
        /// 知识提问实体
        /// </summary>
        [Display(GroupName = "知识库", Name = "知识提问实体", Description = "知识提问实体")]
        KnowledgeQuestionsEntity = 600602,

        /// <summary>
        /// 答复知识提问
        /// </summary>
        [Display(GroupName = "知识库", Name = "答复知识提问", Description = "答复知识提问")]
        ReplyKnowledgeQuestions = 600603,
        #endregion

        #region 知识收藏
        /// <summary>
        /// 知识库收藏
        /// </summary>
        [Display(GroupName = "知识库",Name ="知识库收藏",Description = "知识库收藏")]
        KnowledgeCollect = 600700,

        /// <summary>
        /// 知识收藏列表
        /// </summary>
        [Display(GroupName = "知识库", Name = "知识收藏列表", Description = "知识收藏列表")]
        KnowledgeCollectList = 600701,

        /// <summary>
        /// 知识收藏
        /// </summary>
        [Display(GroupName = "知识库", Name = "知识收藏", Description = "知识收藏")]
        AddKnowledgeCollect = 600702,

        /// <summary>
        /// 知识评分
        /// </summary>
        [Display(GroupName = "知识库", Name = "知识评分", Description = "知识评分")]
        AddKnowledgeScore = 600703,
        #endregion

        #region 知识库基础设置
        /// <summary>
        /// 知识库基础设置
        /// </summary>
        [Display(GroupName = "知识库", Name = "知识库基础设置", Description = "知识库基础设置")]
        KnowledgeBasicSettings = 600800,

        #region 知识规范
        /// <summary>
        /// 知识规范
        /// </summary>
        [Display(GroupName = "知识库", Name = "知识规范", Description = "知识规范")]
        KnowledgeStandard = 600801,
        /// <summary>
        /// 查询知识规范
        /// </summary>
        [Display(GroupName = "知识库", Name = "查询知识规范", Description = "查询知识规范")]
        KnowledgeStandardInfo = 600802,
        /// <summary>
        /// 修改知识规范
        /// </summary>
        [Display(GroupName = "知识库", Name = "修改知识规范", Description = "修改知识规范")]
        KnowledgeStandardUpdate = 600803,

        #endregion

        #region 类型管理
        /// <summary>
        /// 知识类型管理
        /// </summary>
        [Display(GroupName = "知识库",Name ="知识类型管理",Description = "知识类型管理")]
        KnowledgeTypeMange = 600900,
        /// <summary>
        /// 类型管理列表
        /// </summary>
        [Display(GroupName = "知识库", Name = "类型管理列表", Description = "类型管理列表")]
        KnowledgeTypeMangeList = 600901,
        /// <summary>
        /// 添加分类
        /// </summary>
        [Display(GroupName = "知识库", Name = "添加分类", Description = "添加分类")]
        AddKnowledgeType = 600902,
        /// <summary>
        /// 修改分类
        /// </summary>
        [Display(GroupName = "知识库", Name = "修改分类", Description = "修改分类")]
        UpdateKnowledgeType = 600903,
        /// <summary>
        /// 删除分类
        /// </summary>
        [Display(GroupName = "类型管理", Name = "删除分类", Description = "删除分类")]
        RemoveKnowledgeType = 600904,
        #endregion

        #endregion

        #endregion

        #region 辅助功能（70,00,00）

        /// <summary>
        /// 辅助功能
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "辅助功能", Description = "辅助功能")]
        Auxiliary = 700000,

        #region 公告
        /// <summary>
        /// 公告
        /// </summary>
        [Display(GroupName = "辅助功能",Name = "公告",Description = "公告")]
        Bulletin = 700100,
        /// <summary>
        /// 新增公告
        /// </summary>
        [Display(GroupName = "AddBulletin", Name = "新增公告", Description = "新增公告")]
        AddBulletin = 700103,
        /// <summary>
        /// 审核公告
        /// </summary>
        [Display(GroupName = "ExamineBulletin", Name = "审核公告", Description = "审核公告")]
        ExamineBulletin = 700104,

        /// <summary>
        /// 提交公告
        /// </summary>
        [Display(GroupName = "CommitBulletin", Name = "提交公告", Description = "提交公告")]
        CommitBulletin = 700105,
        /// <summary>
        /// 修改公告
        /// </summary>
        [Display(GroupName = "UpdateBulletin", Name = "修改公告", Description = "修改公告")]
        UpdateBulletin = 700106,
        /// <summary>
        /// 删除公告
        /// </summary>
        [Display(GroupName = "DelBulletin", Name = "删除公告", Description = "删除公告")]
        DelBulletin = 700107,
        #endregion

        #region 通知

        /// <summary>
        /// 通知
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "通知", Description = "通知")]
        Circular = 700200,

        /// <summary>
        /// 查询通知列表
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "查询通知列表", Description = "查询通知列表")]
        QueryCircularList = 700201,
        /// <summary>
        /// 新增通知
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "新增通知", Description = "新增通知")]
        AddCircular = 700203,

        /// <summary>
        /// 审核通知
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "审核通知", Description = "审核通知")]
        ExamineCircular = 700204,

        /// <summary>
        /// 提交通知
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "提交通知", Description = "提交通知")]
        CommitCircular = 700205,

        /// <summary>
        /// 修改通知
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "修改通知", Description = "修改通知")]
        UpdateCircular = 700206,

        /// <summary>
        /// 删除通知
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "删除通知", Description = "删除通知")]
        DelCircular = 700207,

        #endregion

        #region 常用意见
        /// <summary>
        /// 常用意见
        /// </summary>
        [Display(GroupName = "辅助功能",Name = "常用意见",Description ="常用意见")]
        CommonOpinion = 700300,
        /// <summary>
        /// 常用意见列表
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "常用意见列表", Description = "常用意见列表")]
        QueryOpenCommonOpinionList = 700301,
        /// <summary>
        /// 修改意见
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "修改意见", Description = "修改意见")]
        CommonModify = 700302,
        #endregion

        #region 工单词库
        /// <summary>
        /// 工单词库
        /// </summary>
        [Display(GroupName = "辅助功能",Name = "工单词库",Description = "工单词库")]
        OrderWord = 700400,

        /// <summary>
        /// 工单词库列表
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "工单词库列表", Description = "工单词库列表")]
		OrderWordList = 700401,

		/// <summary>
		/// 新增工单词库
		/// </summary>
		[Display(GroupName = "辅助功能", Name = "新增工单词库", Description = "新增工单词库")]
		AddOrderWord = 700402,

		/// <summary>
		/// 删除工单词库
		/// </summary>
		[Display(GroupName = "辅助功能", Name = "删除工单词库", Description = "删除工单词库")]
		DeleteOrderWord = 700403,

		/// <summary>
		/// 修改工单词库
		/// </summary>
		[Display(GroupName = "辅助功能", Name = "修改工单词库", Description = "修改工单词库")]
		UpdateOrderWord = 700404,


        #endregion

        #region 知识库词库
        /// <summary>
        /// 知识库词库
        /// </summary>
        [Display(GroupName = "辅助功能",Name = "知识库词库",Description = "知识库词库")]
        KnowledgeWord = 700500,

        /// <summary>
        /// 知识库词库列表
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "知识库词库列表", Description = "知识库词库列表")]
        KnowledgeWordList = 700501,

        /// <summary>
        /// 新增知识库词库
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "新增知识库词库", Description = "新增知识库词库")]
        AddKnowledgeWord = 700502,

        /// <summary>
        /// 删除知识库词库
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "删除知识库词库", Description = "删除知识库词库")]
        DeleteKnowledgeWord = 700503,

        /// <summary>
        /// 修改知识库词库
        /// </summary>
        [Display(GroupName = "辅助功能", Name = "修改知识库词库", Description = "修改知识库词库")]
        UpdateKnowledgeWord = 700504,

        #endregion

        #region 区域管理
        [Display(GroupName = "辅助功能")]
        Area = 700600,
        /// <summary>
        /// 新增区域
        /// </summary>
        [Display(GroupName = "系统设置", Name = "新增区域", Description = "新增区域")]
        AddArea = 700601,
        /// <summary>
        /// 修改区域
        /// </summary>
        [Display(GroupName = "系统设置", Name = "修改区域", Description = "修改区域")]
        ModifyArea = 700602,
        /// <summary>
        /// 删除区域
        /// </summary>
        [Display(GroupName = "系统设置", Name = "删除区域", Description = "删除区域")]
        DelArea = 700603,
        /// <summary>
        /// 获取区域
        /// </summary>
        [Display(GroupName = "系统设置", Name = "获取区域", Description = "获取区域")]
        GetArea = 700604,
        #endregion

        #region 标签管理
        /// <summary>
        /// 标签管理
        /// </summary>
        [Display(GroupName = "辅助功能",Name = "标签管理",Description ="标签管理")]
        BusinessTag = 700700,
        /// <summary>
        /// 标签列表
        /// </summary>
        [Display(GroupName = "辅助功能",Name = "标签列表",Description = "标签列表")]
        BusinessTagList = 700701,
        /// <summary>
        /// 新增标签
        /// </summary>
        [Display(GroupName = "辅助功能",Name ="新增标签",Description ="新增标签")]
        AddBusinessTag = 700702,
        /// <summary>
        /// 删除标签
        /// </summary>
        [Display(GroupName ="辅助功能",Name ="删除标签",Description ="删除标签")]
        DeleteBusinessTag = 700703,
        /// <summary>
        /// 修改标签
        /// </summary>
        [Display(GroupName ="辅助功能",Name ="修改标签",Description ="修改标签")]
        UpdateBusinessTag = 700704,
        /// <summary>
        /// 获取标签实体
        /// </summary>
        [Display(GroupName ="辅助功能",Name = "获取标签实体", Description ="获取标签实体")]
        BusinessTagEntity = 700705,
        /// <summary>
        /// 标签绑定
        /// </summary>
        [Display(GroupName ="辅助功能",Name ="标签绑定",Description ="标签绑定")]
        BusinessTagBinding = 700706,
        #endregion

        #region 短信中心
        /// <summary>
        /// 短信中心
        /// </summary>
        [Display(GroupName = "辅助功能",Name ="短信中心",Description ="短信中心")]
        PushMessage = 700800,
        /// <summary>
        /// 短信列表
        /// </summary>
        [Display(GroupName ="辅助功能",Name ="短信列表",Description ="短信列表")]
        AllMessage  = 700801,
        /// <summary>
        /// 重新发送
        /// </summary>
        [Display(GroupName = "辅助功能",Name ="重新发送",Description ="重新发送")]
        SendAgain = 700802,
        #endregion

        #region 事件分类管理
        /// <summary>
        /// 事件分类管理
        /// </summary>
        [Display(GroupName ="辅助功能",Name ="事件分类管理",Description = "事件分类管理")]
        EventClassManage = 700900,
        /// <summary>
        /// 新增事件
        /// </summary>
        [Display(GroupName ="辅助功能",Name ="新增事件",Description ="新增事件")]
        AddEvent = 700901,
        /// <summary>
        /// 删除事件
        /// </summary>
        [Display(GroupName ="辅助功能",Name ="删除事件",Description ="删除事件")]
        DelEvent = 700902,
        #endregion

        #endregion

        #region 话务管理（80,00,00）
        /// <summary>
        /// 话务管理
        /// </summary>
        [Display(GroupName = "话务管理",Name = "话务管理",Description = "话务管理")]
        Call = 800000,
        #region 通讯记录
        /// <summary>
        /// 通讯记录
        /// </summary>
        [Display(GroupName ="话务管理",Name = "通讯记录",Description ="通讯记录")]
        CallLog = 800100,
        /// <summary>
        /// 关联业务
        /// </summary>
        [Display(GroupName ="话务管理",Name ="关联业务",Description ="关联业务")]
        LinkCall = 800101,
        #endregion

        #region 黑白名单

        /// <summary>
        /// 黑白名单
        /// </summary>
        [Display(GroupName = "话务管理",Name ="黑白名单",Description ="黑白名单")]
        BlackList = 800200,
        /// <summary>
        /// 分页查询黑名单
        /// </summary>
        [Display(GroupName = "黑名单管理", Name = "分页查询黑名单", Description = "分页查询黑名单")]
        QueryPagedBlack = 800201,
        /// <summary>
        /// 添加电话号至黑名单
        /// </summary>
        [Display(GroupName = "黑名单管理", Name = "添加电话号至黑名单", Description = "添加电话号至黑名单")]
        AddBlackList = 800202,
        /// <summary>
        /// 删除黑名单数据
        /// </summary>
        [Display(GroupName = "黑名单管理", Name = "删除黑名单数据", Description = "删除黑名单数据")]
        RemoveBlacklist = 800203,
        #endregion

        #region 分机管理
        /// <summary>
        /// 分级管理
        /// </summary>
        [Display(GroupName ="话务管理",Name ="分机管理",Description ="分级管理")]
        TelManage = 800300,
        /// <summary>
        /// 监听分机
        /// </summary>
        [Display(GroupName ="话务管理",Name ="监听分机",Description ="监听分机")]
        ListenInTel = 800301,
        #endregion

        #endregion

        #region 智能化管理（90,00,00）
        /// <summary>
        /// 智能化
        /// </summary>
        [Display(GroupName = "智能化",Name ="智能化",Description = "智能化")]
        Intellect  = 900000,

        #region 智能化语音导航
        /// <summary>
        /// 智能化语音导航
        /// </summary>
        [Display(GroupName = "智能化",Name ="智能化语音导航",Description ="智能化语音导航")]
        IntellectIvr = 900100,
        #endregion
        #region 智能质检
        /// <summary>
        /// 智能质检
        /// </summary>
        [Display(GroupName = "智能化",Name ="智能质检",Description ="智能质检")]
        IntellectQuality = 900200,
        #endregion
        #region 智能回访
        /// <summary>
        /// 智能回访
        /// </summary>
        [Display(GroupName = "智能化",Name ="智能回访",Description ="智能回访")]
        IntellectVisit = 900300,
        #endregion

        #endregion

        #region 大屏管理（12,00,00）
        /// <summary>
        /// 大屏管理
        /// </summary>
        [Display(GroupName = "大屏管理",Name = "大屏管理",Description ="大屏管理")]
        ScreenManage = 120000,

        #region 大屏数据
        /// <summary>
        /// 数据大屏
        /// </summary>
        [Display(GroupName ="大屏管理",Name = "数据大屏",Description ="数据大屏")]
        ScreenData = 120100,
        /// <summary>
        /// 坐席监控
        /// </summary>
        [Display(GroupName = "大屏管理",Name ="坐席监控",Description ="坐席监控")]
        SeatMonitor = 120200,

        #endregion
        #endregion

        #region 数据统计（110000）
        /// <summary>
        /// 数据统计
        /// </summary>
        [Display(GroupName = "数据统计",Name ="数据统计",Description ="数据统计")]
        DataCanter = 110000,

        #region 话务统计
        /// <summary>
        /// 话务统计
        /// </summary>
        [Display(GroupName = "数据统计",Name ="话务统计",Description ="话务统计")]
        CallStatistics = 110100,
        /// <summary>
        /// 话务统计分析
        /// </summary>
        [Display(GroupName = "数据统计",Name = "话务统计分析",Description ="话务统计分析")]
        CallStatisticsAnalysis = 110101,
        /// <summary>
        /// 坐席话务统计分析
        /// </summary>
        [Display(GroupName = "数据统计",Name = "坐席话务统计分析",Description ="坐席话务统计分析")]
        SeatCallStatisticsAnalysis = 110102,
        /// <summary>
        /// 话机动作统计
        /// </summary>
        [Display(GroupName = "数据统计",Name = "话机动作统计",Description = "话机动作统计")]
        TelActStatistics = 110103,
        /// <summary>
        /// 转外线统计分析
        /// </summary>
        [Display(GroupName ="数据统计",Name = "转外线统计分析",Description ="转外线统计分析")]
        TelOutStatistics = 110104,
        /// <summary>
        /// 坐席小休统计表
        /// </summary>
        [Display(GroupName ="数据统计",Name ="坐席小休统计表",Description ="坐席小休统计表")]
        SeatRestStatistics = 110105,
        #endregion

        #region 工单统计
        /// <summary>
        /// 工单统计
        /// </summary>
        [Display(GroupName = "数据统计",Name = "工单统计",Description ="工单统计")]
        OrderStatistics = 110200,
        /// <summary>
        /// 中心统计
        /// </summary>
        [Display(GroupName = "数据统计",Name = "中心统计",Description ="中心统计")]
        CenterStatistics = 110201,
        /// <summary>
        /// 部门超期统计
        /// </summary>
        [Display(GroupName = "数据统计",Name = "部门超期统计",Description ="部门超期统计")]
        OrgOverdueStatistics = 110202,
        /// <summary>
        /// 部门延期统计
        /// </summary>
        [Display(GroupName ="数据统计",Name ="部门延期统计",Description ="部门延期统计")]
        OrgDelayStatistics = 110203,
        /// <summary>
        /// 回访不满意原因统计
        /// </summary>
        [Display(GroupName ="数据统计",Name = "回访不满意原因统计",Description ="回访不满意原因统计")]
        VisitNoSatisfiedReasonStatistics = 110204,
        /// <summary>
        /// 不满意回访明细
        /// </summary>
        [Display(GroupName = "数据统计",Name = "不满意回访明细",Description ="不满意回访明细")]
        VisitNoSatisfiedDetailStatistics = 110205,
        /// <summary>
        /// 特提统计
        /// </summary>
        [Display(GroupName = "数据统计",Name ="特提统计",Description ="特提统计")]
        SpecialRetrieveStatistics = 110206,
        /// <summary>
        /// 特提统计明细
        /// </summary>
        [Display(GroupName ="数据统计",Name ="特提统计明细",Description ="特提统计明细")]
        SpecialRetrieveDetailStatistics = 110207,
        #endregion

        #region 知识库统计
        /// <summary>
        /// 知识库统计
        /// </summary>
        [Display(GroupName = "数据统计",Name ="知识库统计",Description ="知识库统计")]
        KnowledgeStatistics = 110300,
        /// <summary>
        /// 知识库数据统计
        /// </summary>
        [Display(GroupName ="数据统计",Name ="知识库数据统计",Description ="知识库数据统计")]
        KnowledgeDataStatistics = 110301,
        #endregion

        #endregion

        #region 公用（99，00,00）

        #region 话机操作面板权限
        /// <summary>
        /// 通知阅读
        /// </summary>
        [Display(GroupName = "公用",Name ="通知阅读",Description ="通知阅读")]
        Readed = 990101,

        /// <summary>
        /// 坐席面板
        /// </summary>
        [Display(GroupName = "公用", Name = "坐席面板", Description = "坐席面板")]
        TelPanel = 990103,

        #endregion
        
        #endregion

	}
}